/*
 * @package   ats
 * @copyright Copyright (c)2011-2020 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

if (typeof (akeeba) === "undefined")
{
    var akeeba = {};
}

if (typeof (akeeba.jQuery) === "undefined")
{
    akeeba.jQuery = window.jQuery.noConflict();
}

if (typeof (akeeba.ats) === "undefined")
{
    akeeba.ats = {};
}

if (typeof (akeeba.ats.timecards) === "undefined")
{
    akeeba.ats.timecards = {
        timeChart: null,
    };
}

akeeba.ats.timecards.load = function () {
    (function ($) {
        $.ajax("index.php?option=com_ats&view=TimeCards&task=browse&format=json", {
            dataType: "json",
            cache:    false,
            data:     {
                "limitstart":   0,
                "limit":        0,
                "sumtimespent": 1,
                "created_on":   {
                    "from":    document.getElementById("time_start").value,
                    "to":      document.getElementById("time_end").value,
                    "method":  "between",
                    "include": true
                },
            },
            success:  function (data) {
                akeeba.ats.timecards.renderGraph(data);
            }
        });
    })(akeeba.jQuery);
};

akeeba.ats.timecards.renderGraph = function (data) {
	var chartOptions = {
		type:    "bar",
		data:    {
			datasets: [
				{
					label:           "Hours",
					data:            data.data,
					backgroundColor: "#40B5B8",
					fill:            true,
					yAxisID:         "y-axis-hours",
				}
			]
		},
		options: {
			legend: {
				display: false
			},
			scales: {
				xAxes: [
					{
						type:   "category",
						labels: data.labels,
						ticks: {
							fontColor: '#F0AD4E'
						}
					}
				],
				yAxes: [
					{
						id:       "y-axis-hours",
						position: "left",
						ticks:    {
							fontColor: '#40B5B8',
							beginAtZero: true
						}
					}
				]
			}
		}
	};

	if (akeeba.ats.timecards.timeChart)
	{
		akeeba.ats.timecards.timeChart.destroy();
		akeeba.ats.timecards.timeChart = null;
	}

	akeeba.ats.timecards.timeChart = new Chart(document.getElementById("ats-timecard"), chartOptions);
};

akeeba.jQuery(document).ready(function () {
    akeeba.jQuery("#time_graph_reload").click(akeeba.ats.timecards.load);

	akeeba.ats.timecards.load();
});
